@@ -3,7 +3,8 @@
  * Released under the GPL.
  * copyright Maher Awamy <muhri@muhri.net>
  * 	     Aaron Lehmann <aaronl@vitelus.com>
- * 	     Joshua Kwan <joshk@triplehelix.org> */
+ * 	     Joshua Kwan <joshk@triplehelix.org> 
+ * 	     Pedro Villavicencio Garrido <pvillavi@gnome.cl> */
 
 #include "expand.xpm"
 #include "switch.h"
@@ -228,11 +229,27 @@ write_rc_file (gchar *include_file, gchar *path)
 	fclose (gtkrc);
 }
 
+static void 
+backup_gtkrc(gchar *path_to_gtkrc)
+{
+	FILE *gtkrc;
+
+	if(!(gtkrc = fopen(path_to_gtkrc, "r")))
+		return;
+	int c;
+	FILE *gtkrc_backup = fopen(g_strdup_printf("%s/.gtkrc.bak", homedir), "w");
+
+	while((c = fgetc(gtkrc)) != EOF){
+		fputc(c, gtkrc_backup);
+	}
+}
+
 static void
 ok_clicked (gchar *rc_file)
 {
 	/* Write the config file to disk */
 	gchar *path_to_gtkrc = g_strdup_printf("%s/.gtkrc", homedir);
+	backup_gtkrc(path_to_gtkrc);
 	write_rc_file (rc_file, path_to_gtkrc);
 	send_refresh_signal();
 	g_free(path_to_gtkrc);
